Learn R Programming

nestedcv (version 0.9.0)

boot_filter: Bootstrap for filter functions

Description

Randomly samples predictors and averages the ranking to give an ensemble measure of predictor variable importance.

Usage

boot_filter(y, x, filterFUN, B = 50, nfilter = NULL, type = "index", ...)

Value

Integer vector of indices of filtered parameters (type = "index") or if type = "full" a matrix of rankings from each bootstrap is returned.

Arguments

y

Response vector

x

Matrix of predictors

filterFUN

Filter function, e.g. ttest_filter().

B

Number of times to bootstrap

nfilter

Number of predictors to return

type

Type of vector returned. Default "index" returns indices, "full" returns full output.

...

Optional arguments passed to the function specified by filterFUN

See Also

boot_ttest()