Randomly samples predictors and averages the ranking from filtering functions
including ttest_filter(), wilcoxon_filter(), anova_filter(),
correl_filter() and lm_filter() to give an ensemble measure of best
predictors by repeated random sampling subjected to a statistical test.
boot_ttest(y, x, B = 50, ...)boot_wilcoxon(y, x, B = 50, ...)
boot_anova(y, x, B = 50, ...)
boot_correl(y, x, B = 50, ...)
boot_lm(y, x, B = 50, ...)
Integer vector of indices of filtered parameters (type = "index"),
or if type = "full", a matrix of rankings from each bootstrap is
returned.
Response vector
Matrix of predictors
Number of times to bootstrap
Optional arguments passed to the filter function
ttest_filter(), wilcoxon_filter(), anova_filter(),
correl_filter(), lm_filter() and boot_filter()