Learn R Programming

nestedcv (version 0.9.0)

coef.nestcv.glmnet: Extract coefficients from nestcv.glmnet object

Description

Extracts coefficients from the final fit of a "nestcv.glmnet" object.

Usage

# S3 method for nestcv.glmnet
coef(object, s = object$final_param["lambda"], ...)

Value

Vector or list of coefficients ordered with the intercept first, followed by highest absolute value to lowest.

Arguments

object

Object of class "nestcv.glmnet"

s

Value of penalty parameter lambda. Default is the mean of lambda values selected across each outer fold.

...

Other arguments passed to glmnet::coef.glmnet()