Plot of cross-validated glmnet lambda parameter against deviance for each outer CV fold.
plot_lambdas(
x,
scheme = NULL,
palette = "Dark 3",
showLegend = if (x$outer_method == "cv") "topright" else NULL,
...
)No return value
Fitted "nestcv.glmnet" object
colour scheme
palette name (one of hcl.pals()) which is passed to
hcl.colors
Either a keyword to position the legend or NULL to hide
the legend.
other arguments passed to plot. Use type = 'p' to plot a
scatter plot instead of a line plot.
Myles Lewis
nestcv.glmnet