Makes predictions from a cross-validated glmnet model with optimal value of lambda and alpha.
# S3 method for cva.glmnet
predict(object, newx, s = "lambda.1se", ...)Object returned depends on arguments in ... such as type.
Fitted cva.glmnet object.
Matrix of new values for x at which predictions are to be made.
Value of penalty parameter lambda. Default value is s="lambda.1se"
for consistency with glmnet. Alternatively s="lambda.min" can be used.
Other arguments passed to predict.cv.glmnet().