Fits a random forest model via the ranger package and ranks variables by
variable importance.
ranger_filter(
y,
x,
nfilter = NULL,
type = c("index", "names", "full"),
num.trees = 1000,
mtry = ncol(x) * 0.2,
...
)Integer vector of indices of filtered parameters (type = "index") or
character vector of names (type = "names") of filtered parameters. If
type is "full" a named vector of variable importance is returned.
Response vector
Matrix or dataframe of predictors
Number of predictors to return. If NULL all predictors are
returned.
Type of vector returned. Default "index" returns indices, "names" returns predictor names, "full" returns a named vector of variable importance.
Number of trees to grow. See ranger::ranger.
Number of predictors randomly sampled as candidates at each split. See ranger::ranger.
Optional arguments passed to ranger::ranger.
This filter uses the ranger() function from the ranger package. Variable
importance is calculated using mean decrease in gini impurity.