Fits a random forest model and ranks variables by variable importance.
rf_filter(
y,
x,
nfilter = NULL,
type = c("index", "names", "full"),
ntree = 1000,
mtry = ncol(x) * 0.2,
...
)Integer vector of indices of filtered parameters (type = "index") or
character vector of names (type = "names") of filtered parameters. If
type is "full" a named vector of variable importance is returned.
Response vector
Matrix or dataframe of predictors
Number of predictors to return. If NULL all predictors are
returned.
Type of vector returned. Default "index" returns indices, "names" returns predictor names, "full" returns a named vector of variable importance.
Number of trees to grow. See randomForest::randomForest.
Number of predictors randomly sampled as candidates at each split. See randomForest::randomForest.
Optional arguments passed to randomForest::randomForest.
This filter uses the randomForest() function from the randomForest
package. Variable importance is calculated using the
randomForest::importance function, specifying type 1 = mean decrease in
accuracy. See randomForest::importance.