Slims nestedcv objects to only the models in the outer CV folds.
Usage
slim(x)
Value
For 'nestedcv' objects, a list object of the same class but only
containing outer_result. For 'cva.glmnet' models, only the cv.glmnet
model with the best alpha value is kept. Models for all other values of
alpha are discarded.