Learn R Programming

nestedcv (version 0.9.0)

summary_vars: Summarise variables

Description

Summarise variables

Usage

summary_vars(x)

Value

A matrix with variables in rows and mean, median and SD for each variable or number of levels if the variable is a factor. If NA are detected, an extra column n.NA is added with the numbers of NA for each variable.

Arguments

x

Matrix or dataframe with variables in columns