Performs supervised principle component analysis (PCA) after filtering dataset to help determine whether filtering has been useful for separating samples according to the outcome variable.
supervisedPCA(y, x, filterFUN = NULL, filter_options = NULL, plot = TRUE, ...)If plot=TRUE returns a ggplot2 plot, otherwise returns the
principle component scores.
Response vector
Matrix of predictors
Filter function, e.g. ttest_filter or relieff_filter.
Any function can be provided and is passed y and x. Must return a
character vector with names of filtered predictors.
List of additional arguments passed to the filter
function specified by filterFUN.
Logical whether to plot a ggplot2 object or return the PC scores
Optional arguments passed to princomp()