Obtain predictions on outer training folds which can be used for performance metrics and ROC curves.
train_preds(x)Dataframe with columns ytrain and predy containing observed and
predicted values from training folds. For binomial and multinomial models
additional columns are added with class probabilities or log likelihood
values.
a nestcv.glmnet, nestcv.train or outercv fitted object
Note: the argument outer_train_predict must be set to TRUE in
the original call to either nestcv.glmnet, nestcv.train or outercv.