Text progress bar in the R console. Modified from utils::txtProgressBar()
to include title and timing.
txtProgressBar2(
min = 0,
max = 1,
initial = 0,
char = "=",
width = NA,
title = ""
)An object of class "txtProgressBar".
Numeric value for minimum of the progress bar.
Numeric value for maximum of the progress bar.
Initial value for the progress bar.
The character (or character string) to form the progress bar.
The width of the progress bar, as a multiple of the width of
char. If NA, the default, the number of characters is that which fits
into getOption("width").
Title for the progress bar.
Use utils::setTxtProgressBar() to set the progress bar and close() to
close it.