Learn R Programming

nestedcv (version 0.9.0)

var_direction: Variable directionality

Description

Determines directionality of final predictors for binary or regression models, using the sign of the t-statistic or correlation coefficient respectively for each variable compared to the outcomes.

Usage

var_direction(object)

Value

named vector showing the directionality of final predictors. If the response vector is multinomial NULL is returned.

Arguments

object

a nestcv.glmnet or nestcv.train fitted model

Details

Categorical features with >2 levels are assumed to have a meaningful order for the purposes of directionality. Factors are coerced to ordinal using data.matrix(). If factors are multiclass then directionality results should be ignored.