Randomly samples predictors and averages the ranking to give an ensemble measure of predictor variable importance.
boot_filter(y, x, filterFUN, B = 50, nfilter = NULL, type = "index", ...)Integer vector of indices of filtered parameters (type = "index")
or if type = "full" a matrix of rankings from each bootstrap is returned.
Response vector
Matrix of predictors
Filter function, e.g. ttest_filter().
Number of times to bootstrap
Number of predictors to return
Type of vector returned. Default "index" returns indices, "full" returns full output.
Optional arguments passed to the function specified by filterFUN
boot_ttest()