Extracts coefficients from the final fit of a "nestcv.glmnet" object.
# S3 method for nestcv.glmnet
coef(object, s = object$final_param["lambda"], ...)Vector or list of coefficients ordered with the intercept first, followed by highest absolute value to lowest.
Object of class "nestcv.glmnet"
Value of penalty parameter lambda. Default is the mean of lambda values selected across each outer fold.
Other arguments passed to glmnet::coef.glmnet()