powered by
Summarise variables
summary_vars(x)
A matrix with variables in rows and mean, median and SD for each variable or number of levels if the variable is a factor. If NA are detected, an extra column n.NA is added with the numbers of NA for each variable.
NA
n.NA
Matrix or dataframe with variables in columns